@@ -288,7 +288,9 @@ class DamonTarget:
         self.regions = regions
 
     def to_str(self, raw):
-        lines = ['pid: %s' % self.pid]
+        lines = []
+        if self.pid is not None:
+            lines.append('pid: %s' % self.pid)
         for region in self.regions:
             lines.append('region %s' % region.to_str(raw))
         return '\n'.join(lines)
@@ -826,20 +828,28 @@ class Damos:
             for region in self.tried_regions:
                 self.tried_bytes += region.size()
 
-    def to_str(self, raw):
-        lines = ['action: %s per %s' % (self.action,
-            _damo_fmt_str.format_time_us(self.apply_interval_us, raw)
-            if self.apply_interval_us != 0 else 'aggr interval')]
-        lines.append('target access pattern')
-        lines.append(_damo_fmt_str.indent_lines(
-            self.access_pattern.to_str(raw), 4))
-        lines.append('quotas')
-        lines.append(_damo_fmt_str.indent_lines(self.quotas.to_str(raw), 4))
-        lines.append('watermarks')
-        lines.append(_damo_fmt_str.indent_lines(
-            self.watermarks.to_str(raw), 4))
+    def str_action_line(self, raw):
+        action_words = ['action: %s' % self.action]
         if is_damos_migrate_action(self.action):
-            lines.append('target_nid: %s' % self.target_nid)
+            action_words.append('to node %s' % self.target_nid)
+        action_words.append('per %s' %
+            _damo_fmt_str.format_time_us(self.apply_interval_us, raw)
+            if self.apply_interval_us != 0 else 'per aggr interval')
+        return ' '.join(action_words)
+
+    def to_str(self, raw):
+        lines = [self.str_action_line(raw)]
+        if self.access_pattern is not None:
+            lines.append('target access pattern')
+            lines.append(_damo_fmt_str.indent_lines(
+                self.access_pattern.to_str(raw), 4))
+        if self.quotas is not None:
+            lines.append('quotas')
+            lines.append(_damo_fmt_str.indent_lines(self.quotas.to_str(raw), 4))
+        if self.watermarks is not None:
+            lines.append('watermarks')
+            lines.append(_damo_fmt_str.indent_lines(
+                self.watermarks.to_str(raw), 4))
         for idx, damos_filter in enumerate(self.filters):
             lines.append('filter %d' % idx)
             lines.append(_damo_fmt_str.indent_lines(
@@ -995,13 +1005,20 @@ class Kdamond:
             ctx.kdamond = self
 
     def summary_str(self, show_cpu=False):
-        ret = 'state: %s, pid: %s' % (self.state, self.pid)
+        words = []
+        if self.state is not None:
+            words.append('state: %s' % self.state)
+        if self.pid is not None:
+            words.append('pid: %s' % self.pid)
         if show_cpu:
-            ret += ', cpu usage: %s' % self.get_cpu_usage()
-        return ret
+            words.append('cpu usage: %s' % self.get_cpu_usage())
+        return ', '.join(words)
 
     def to_str(self, raw, show_cpu=False):
-        lines = [self.summary_str(show_cpu)]
+        lines = []
+        summary_line = self.summary_str(show_cpu)
+        if summary_line != '':
+            lines.append(summary_line)
         for idx, ctx in enumerate(self.contexts):
             lines.append('context %d' % idx)
             lines.append(_damo_fmt_str.indent_lines(ctx.to_str(raw), 4))
