@@ -96,91 +96,118 @@ def schemes_option_to_damos(schemes):
     except Exception as json_err:
         return None, '%s' % json_err
 
-def handle_err_get_filter_pass(filter_type, optional_args):
-    '''
-    optional_args are for filter target memory type specification, and whether
-    the filter is pass filter or block filter.
-    Target memory type specification options depend on the type.
-    Whether to pass or block is optional (block by default)
-    '''
-    type_to_nr_type_args = {
-            'anon': 0,
-            'memcg': 1,
-            'young': 0,
-            'addr': 2,
-            'target': 1}
-    if not filter_type in type_to_nr_type_args:
-        return None, 'unsupported filter target type'
-    nr_type_args = type_to_nr_type_args[filter_type]
-    len_args = len(optional_args)
-    if len_args < nr_type_args:
-        return None, '<%d filter optional args (%s)' % (
-                nr_rype_args, optional_args)
-    elif len_args > nr_type_args + 1:
-        return None, '>%d filter optional args (%s)' % (
-                nr_type_args + 1, optional_args)
+def damos_filter_with_optional_args(ftype, fmatching, allow, optional_words):
+    # return filter, error, and number of consumed words
+    if ftype == 'memcg':
+        if len(optional_words) < 1:
+            return None, 'no memcg path is given', 0
+        memcg_path = optional_words[0]
+        return _damon.DamosFilter(ftype, fmatching, memcg_path=memcg_path,
+                                  allow=allow), None, 1
+    if ftype == 'addr':
+        if len(optional_words) < 2:
+            return None, 'no address range is given', 0
+        try:
+            addr_range = _damon.DamonRegion(optional_words[0], optional_words[1])
+        except Exception as e:
+            return None, 'wrong addr range (%s, %s)' % (optional_words, e), 0
+        return _damon.DamosFilter(ftype, fmatching, allow=allow,
+                                  address_range=addr_range), None, 2
+    elif ftype == 'target':
+        if len(optional_words) < 1:
+            return None, 'no target argument', 0
+        try:
+            return _damon.DamosFilter(
+                    ftype, fmatching, allow=allow,
+                    damon_target_idx=optional_words[0]), None, 1
+        except Exception as e:
+            return None, 'target filter creation failed (%s, %s)' % (
+                    optional_words[0], e), 0
+    else:
+        return None, 'unsupported filter type', 0
 
-    if len_args == nr_type_args:
-        return False, None
-    filter_pass_keyword = optional_args[-1]
-    if not filter_pass_keyword in ['pass', 'block']:
-        return None, 'wrong filter_pass keyword (%s)' % filter_pass_keyword
-    return filter_pass_keyword == 'pass', None
+def damos_options_to_filter_v2(words):
+    '''
+    Returns filter, error, and consumed number of words
+    '''
+    if len(words) < 2:
+        return None, 'wrong number of words: %s' % words, 0
+    if not words[0] in ['allow', 'reject']:
+        return None, 'first word should be allow or reject', 0
+    allow = words[0] == 'allow'
+    nr_consumed_words = 1
+    word = words[nr_consumed_words]
+    if word == 'none':
+        fmatching = False
+        nr_consumed_words += 1
+    else:
+        fmatching = True
+    ftype = words[nr_consumed_words]
+    nr_consumed_words += 1
+
+    if ftype in ['anon', 'young', 'hugepage']:
+        filter = _damon.DamosFilter(ftype, fmatching, allow=allow)
+        return filter, None, nr_consumed_words
+    else:
+        filter, err, nr_words = damos_filter_with_optional_args(
+                ftype, fmatching, allow, words[nr_consumed_words:])
+        if err is not None:
+            return None, 'handling %s fail (%s)' % (words, err), 0
+        return filter, None, nr_consumed_words + nr_words
+
+def damos_options_to_filters_v2(words):
+    filters = []
+    while len(words) > 0:
+        filter, err, nr_consumed_words = damos_options_to_filter_v2(words)
+        if err is not None:
+            return None, err
+        filters.append(filter)
+        words = words[nr_consumed_words:]
+    return filters, None
+
+def convert_damos_filter_v1_to_v2(filter_args):
+    if len(filter_args) < 2:
+        return None, '<2 filter argument'
+    filter_type = filter_args[0]
+    matching = filter_args[1] == 'matching'
+    optional_args = filter_args[2:]
+    if len(optional_args) == 0:
+        allow_reject = 'reject'
+    else:
+        if optional_args[-1] in ['allow', 'pass', 'reject', 'block']:
+            if optional_args[-1] in ['allow', 'pass']:
+                allow_reject = 'allow'
+            else:
+                allow_reject = 'reject'
+            optional_args = optional_args[:-1]
+        else:
+            allow_reject = 'reject'
+    v2_args = [allow_reject]
+    if matching is False:
+        v2_args.append('none')
+    return v2_args + [filter_type] + optional_args, None
 
 def damos_options_to_filters(filters_args):
     filters = []
     if filters_args == None:
         return filters, None
 
+    full_words = []
     for fields in filters_args:
-        if len(fields) < 2:
-            return None, '<2 filter field length (%s)' % fields
-        ftype = fields[0]
-        fmatching = fields[1]
-        fargs = fields[2:]
-        if not fmatching in ['matching', 'nomatching']:
-            return None, 'unsupported matching keyword (%s)' % fmatching
-        fmatching = fmatching == 'matching'
-        filter_pass, err = handle_err_get_filter_pass(ftype, fargs)
-        if err is not None:
-            return None, 'filter arguments handling failed (%s)' % fargs
+        full_words += fields
+    filters, v2_err = damos_options_to_filters_v2(full_words)
+    if v2_err is None:
+        return filters, None
 
-        if ftype == 'anon':
-            filters.append(_damon.DamosFilter(
-                ftype, fmatching, filter_pass=filter_pass))
-        elif ftype == 'memcg':
-            memcg_path = fargs[0]
-            filters.append(_damon.DamosFilter(
-                ftype, fmatching, memcg_path=memcg_path,
-                filter_pass=filter_pass))
-        elif ftype == 'young':
-            filters.append(_damon.DamosFilter(
-                ftype, fmatching, filter_pass=filter_pass))
-        elif ftype == 'addr':
-            if len(fargs) != 2:
-                return None, 'wrong number of addr arguments (%s)' % fargs
-            try:
-                addr_range = _damon.DamonRegion(fargs[0], fargs[1])
-            except Exception as e:
-                return None, 'wrong addr range (%s, %s)' % (fargs, e)
-            filters.append(
-                    _damon.DamosFilter(
-                        ftype, fmatching, filter_pass=filter_pass,
-                        address_range=addr_range))
-        elif ftype == 'target':
-            if len(fargs) != 1:
-                return None, 'wrong number of target argument (%s)' % fargs
-            try:
-                filters.append(
-                        _damon.DamosFilter(
-                            ftype, fmatching, filter_pass=filter_pass,
-                            damon_target_idx=fargs[0]))
-            except Exception as e:
-                return None, 'target filter creation failed (%s, %s)' % (
-                        fargs[0], e)
-        else:
-            return None, 'unsupported filter type'
-    return filters, None
+    full_words = []
+    for filter_args in filters_args:
+        converted_filter_args, err = convert_damos_filter_v1_to_v2(filter_args)
+        if err is not None:
+            return None, 'converting format fail (%s, %s)' % (filter_args, err)
+        full_words += converted_filter_args
+
+    filters, v2_err = damos_options_to_filters_v2(full_words)
+    return filters, v2_err
 
 def damos_quotas_cons_arg(cmd_args):
     time_ms = 0
