@@ -120,6 +120,16 @@ snapshot_formatters = [
             '<filters passed type>',
             lambda snapshot, record, fmt: filters_pass_type_of(record),
             'type of <filters passed bytes> memory'),
+        Formatter(
+                '<filters passed bytes>',
+                lambda snapshot, record, fmt:
+                filters_passed_bytes(snapshot, fmt),
+                'bytes of regions that passed DAMOS filters'),
+        Formatter(
+                '<positive access samples ratio>',
+                lambda snapshot, record, fmt:
+                positive_access_sample_ratio(snapshot, record, fmt),
+                'positive access samples ratio'),
         ]
 
 region_formatters = [
@@ -176,6 +186,25 @@ default_record_head_format = 'kdamond <kdamond index> / context <context index>
 default_snapshot_head_format = 'monitored time: [<start time>, <end time>] (<duration>)\n<heatmap>'
 default_snapshot_head_format_without_heatmap = 'monitored time: [<start time>, <end time>] (<duration>)'
 default_region_format = '<index> addr <start address> size <size> access <access rate> age <age>'
+default_snapshot_tail_format = 'total size: <total bytes>'
+
+def filters_passed_bytes(snapshot, fmt):
+    bytes = 0
+    for region in snapshot.regions:
+        if region.sz_filter_passed is None:
+            return 'N/A'
+        bytes += region.sz_filter_passed
+    return _damo_fmt_str.format_sz(bytes, fmt.raw_number)
+
+def positive_access_sample_ratio(snapshot, record, fmt):
+    max_samples_per_region = record.intervals.aggr / record.intervals.sample
+    max_samples = max_samples_per_region * len(snapshot.regions)
+    nr_samples = 0
+    for region in snapshot.regions:
+        region.nr_accesses.add_unset_unit(record.intervals)
+        nr_samples += region.nr_accesses.samples
+    return _damo_fmt_str.format_percent(
+            nr_samples * 100 / max_samples, fmt.raw_number)
 
 def filters_pass_type_of(record):
     ops_filters = [f for f in record.scheme_filters if f.handled_by_ops()]
@@ -364,6 +393,8 @@ class HeatPixel:
         self.total_heat += temperature_of(region, weights) * (region.size())
 
 def heatmap_str(snapshot, record, fmt):
+    if len(snapshot.regions) == 0:
+        return 'n/a (no region)'
     raw = fmt.raw_number
     total_sz = 0
     for region in snapshot.regions:
@@ -988,6 +1019,12 @@ def set_formats(args, records):
                 fmt.format_region += ' df-passed <filters passed bytes>'
                 break
 
+    if fmt.format_snapshot_tail == default_snapshot_tail_format:
+        for record in records:
+            if len(record.scheme_filters) > 0:
+                fmt.format_snapshot_tail += '  df-passed: <filters passed bytes>'
+                break
+
     if fmt.format_snapshot_head == None:
         need_snapshot_head = False
         for record in records:
@@ -1015,6 +1052,54 @@ def handle_ls_keywords(args):
         return True
     return False
 
+class CacheSpec:
+    size = None
+    ways = None
+    sz_line = None
+    nr_cache_sets = None
+
+    def __init__(self, size, ways, sz_line):
+        self.size = size
+        self.ways = ways
+        self.sz_line = sz_line
+
+        self.nr_cache_sets = self.size / self.ways / self.sz_line
+
+    def set_for_pa(self, addr):
+        return addr / self.sz_line % self.nr_cache_sets
+
+def translate_regions_to_cache_space(regions, cache_spec):
+    set_regions = []
+    for i in range(int(cache_spec.nr_cache_sets)):
+        set_regions.append(_damon.DamonRegion(
+            start=i, end=i+1,
+            nr_accesses=0, nr_accesses_unit=_damon.unit_samples,
+            age=0, age_unit=_damon.unit_aggr_intervals))
+    for region in regions:
+        for addr in range(region.start, region.end, cache_spec.sz_line):
+            csidx = int(cache_spec.set_for_pa(addr))
+            if csidx >= len(set_regions):
+                print(csidx, len(set_regions))
+                exit(0)
+            set_regions[csidx].nr_accesses.samples += region.nr_accesses.samples
+    converted = []
+    for set_region in set_regions:
+        if len(converted) == 0:
+            converted.append(set_region)
+            continue
+        if converted[-1].nr_accesses.samples == set_region.nr_accesses.samples:
+            converted[-1].end = set_region.end
+        else:
+            converted.append(set_region)
+    return converted
+
+def translate_records_to_cache_space(records, cs, cw, cl):
+    cache_spec = CacheSpec(cs, cw, cl)
+    for record in records:
+        for snapshot in record.snapshots:
+            snapshot.regions = translate_regions_to_cache_space(
+                    snapshot.regions, cache_spec)
+
 def main(args):
     handled = handle_ls_keywords(args)
     if handled:
@@ -1060,6 +1145,14 @@ def main(args):
         fmt = ReportFormat.from_kvpairs(json.loads(fmt_string))
     else:
         fmt = set_formats(args, records)
+
+    if args.on_cache is not None:
+        sz_cache = _damo_fmt_str.text_to_bytes(args.on_cache[0])
+        ways_cache = _damo_fmt_str.text_to_nr(args.on_cache[1])
+        sz_cache_line = _damo_fmt_str.text_to_bytes(args.on_cache[2])
+        translate_records_to_cache_space(
+                records, sz_cache, ways_cache, sz_cache_line)
+
     for record in records:
         try:
             pr_records(fmt, records)
@@ -1110,7 +1203,7 @@ def add_fmt_args(parser, hide_help=False):
             if not hide_help else argparse.SUPPRESS)
     parser.add_argument(
             '--format_snapshot_tail', metavar='<template>',
-            default='total size: <total bytes>',
+            default=default_snapshot_tail_format,
             help='output format to show at the end of each snapshot'
             if not hide_help else argparse.SUPPRESS)
     parser.add_argument(
@@ -1217,3 +1310,7 @@ def set_argparser(parser):
     add_fmt_args(parser, hide_help=True)
     parser.add_argument('--format', metavar='<json string>',
                         help='visualization format in json format')
+    parser.add_argument(
+            '--on_cache', nargs=3,
+            metavar=('<cache size>', '<cache ways>', '<cache line size>'),
+            help='visualize access patterns on a virtual cache (EXPERIMENTAL)')
